@@ -1,10 +1,11 @@
-from .lambda_function import LambdaFunction
+from .function import LambdaFunction, QueueFunction
 from .api_function import APIFunction
 from jinja2 import Environment, FileSystemLoader
 import os
 import subprocess
 import boto3
 import shutil
+from .queue import Queue
 
 
 class Deployer(object):
@@ -35,6 +36,29 @@ class Deployer(object):
                 )
         return env_vars
 
+    def _get_queues(self):
+        """
+        Determine queues based on classes that inherit form bld.Queue.
+        """
+        queues = []
+        for child in Queue.__subclasses__():
+            print(child.__name__)
+            queues.append({"name": child.__name__.lower()})
+        return queues
+
+    def _get_queue_functions(self):
+        functions = []
+        classes = QueueFunction.__subclasses__()
+        for lambda_class in classes:
+            # inst = lambda_class()
+            print(lambda_class.__name__)
+            if lambda_class.__name__ not in ["APIFunction", "QueueFunction"]:
+                functions.append(
+                    {"name": lambda_class.__name__, "queue": lambda_class.queue}
+                )
+        print(functions)
+        return functions
+
     def _install_reqs(self):
         reqs = os.path.abspath(f"{self.dir}/requirements.txt")
         subprocess.run(["pip", "install", "-r", reqs], check=True)
@@ -48,17 +72,20 @@ class Deployer(object):
 
         # Running files to create subclasses.
         # TODO: Change these from hardcoded to dynamic.
+        exec(open("queues.py").read())
         exec(open("function.py").read())
         exec(open("api.py").read())
 
         # Get all Lambda Functions.
-        # TODO: Check to make sure ignoring the first one is safe.
         lambda_functions = []
         lambda_classes = LambdaFunction.__subclasses__()
-        lambda_classes = lambda_classes[1:]
         for lambda_class in lambda_classes:
-            # inst = lambda_class()
-            lambda_functions.append({"name": lambda_class.__name__})
+            print(lambda_class.__name__)
+            if lambda_class.__name__ not in ["APIFunction", "QueueFunction"]:
+                lambda_functions.append({"name": lambda_class.__name__})
+
+        print("Functions")
+        print(lambda_functions)
 
         # Get all APIFunctions.
         api_functions = []
@@ -74,6 +101,11 @@ class Deployer(object):
         template = self.jinja.get_template("sam.j2")
 
         env_vars = self._get_env_vars()
+        queues = self._get_queues()
+        print(queues)
+
+        queue_functions = self._get_queue_functions()
+        # queue_functions = []
 
         rendered = template.render(
             description="Test",
@@ -82,6 +114,8 @@ class Deployer(object):
             environment_variables=env_vars,
             dynamo_tables=[],
             subdomain=self.project_name,
+            queues=queues,
+            queue_functions=queue_functions,
         )
         f = open(output_file, "w")
         f.write(rendered)
@@ -148,7 +182,7 @@ class Deployer(object):
             "--s3-bucket",
             f"{self.project_name}-{self.environment}",
             "--template-file",
-            "bld.yml",
+            ".aws-sam/build/template.yml",
             "--parameter-overrides",
             f"ENVIRONMENT={self.environment}",
         ]
